# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitoredResourcesSearchArgs', 'MonitoredResourcesSearch']

@pulumi.input_type
class MonitoredResourcesSearchArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 exclude_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 host_name_contains: Optional[pulumi.Input[str]] = None,
                 management_agent_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_contains: Optional[pulumi.Input[str]] = None,
                 property_equals: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 resource_time_zone: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_created_less_than: Optional[pulumi.Input[str]] = None,
                 time_updated_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_updated_less_than: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MonitoredResourcesSearch resource.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] exclude_fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] external_id: External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] host_name: A filter to return resources with host name match.
        :param pulumi.Input[str] host_name_contains: A filter to return resources with host name pattern.
        :param pulumi.Input[str] management_agent_id: A filter to return resources with matching management agent id.
        :param pulumi.Input[str] name: A filter to return resources that match exact resource name.
        :param pulumi.Input[str] name_contains: A filter to return resources that match resource name pattern given. The match is not case sensitive.
        :param pulumi.Input[Mapping[str, Any]] property_equals: Criteria based on resource property.
        :param pulumi.Input[str] resource_time_zone: Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        :param pulumi.Input[str] state: A filter to return resources with matching lifecycle state.
        :param pulumi.Input[str] time_created_greater_than_or_equal_to: Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_created_less_than: Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_greater_than_or_equal_to: Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_less_than: Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] type: A filter to return resources that match resource type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        if exclude_fields is not None:
            pulumi.set(__self__, "exclude_fields", exclude_fields)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if fields is not None:
            pulumi.set(__self__, "fields", fields)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if host_name_contains is not None:
            pulumi.set(__self__, "host_name_contains", host_name_contains)
        if management_agent_id is not None:
            pulumi.set(__self__, "management_agent_id", management_agent_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_contains is not None:
            pulumi.set(__self__, "name_contains", name_contains)
        if property_equals is not None:
            pulumi.set(__self__, "property_equals", property_equals)
        if resource_time_zone is not None:
            pulumi.set(__self__, "resource_time_zone", resource_time_zone)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created_greater_than_or_equal_to is not None:
            pulumi.set(__self__, "time_created_greater_than_or_equal_to", time_created_greater_than_or_equal_to)
        if time_created_less_than is not None:
            pulumi.set(__self__, "time_created_less_than", time_created_less_than)
        if time_updated_greater_than_or_equal_to is not None:
            pulumi.set(__self__, "time_updated_greater_than_or_equal_to", time_updated_greater_than_or_equal_to)
        if time_updated_less_than is not None:
            pulumi.set(__self__, "time_updated_less_than", time_updated_less_than)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="excludeFields")
    def exclude_fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "exclude_fields")

    @exclude_fields.setter
    def exclude_fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "exclude_fields", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "fields")

    @fields.setter
    def fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "fields", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with host name match.
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hostNameContains")
    def host_name_contains(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with host name pattern.
        """
        return pulumi.get(self, "host_name_contains")

    @host_name_contains.setter
    def host_name_contains(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name_contains", value)

    @property
    @pulumi.getter(name="managementAgentId")
    def management_agent_id(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with matching management agent id.
        """
        return pulumi.get(self, "management_agent_id")

    @management_agent_id.setter
    def management_agent_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "management_agent_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match exact resource name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match resource name pattern given. The match is not case sensitive.
        """
        return pulumi.get(self, "name_contains")

    @name_contains.setter
    def name_contains(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_contains", value)

    @property
    @pulumi.getter(name="propertyEquals")
    def property_equals(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Criteria based on resource property.
        """
        return pulumi.get(self, "property_equals")

    @property_equals.setter
    def property_equals(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "property_equals", value)

    @property
    @pulumi.getter(name="resourceTimeZone")
    def resource_time_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        """
        return pulumi.get(self, "resource_time_zone")

    @resource_time_zone.setter
    def resource_time_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_time_zone", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with matching lifecycle state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreatedGreaterThanOrEqualTo")
    def time_created_greater_than_or_equal_to(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_greater_than_or_equal_to")

    @time_created_greater_than_or_equal_to.setter
    def time_created_greater_than_or_equal_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created_greater_than_or_equal_to", value)

    @property
    @pulumi.getter(name="timeCreatedLessThan")
    def time_created_less_than(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_less_than")

    @time_created_less_than.setter
    def time_created_less_than(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created_less_than", value)

    @property
    @pulumi.getter(name="timeUpdatedGreaterThanOrEqualTo")
    def time_updated_greater_than_or_equal_to(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_greater_than_or_equal_to")

    @time_updated_greater_than_or_equal_to.setter
    def time_updated_greater_than_or_equal_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated_greater_than_or_equal_to", value)

    @property
    @pulumi.getter(name="timeUpdatedLessThan")
    def time_updated_less_than(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_less_than")

    @time_updated_less_than.setter
    def time_updated_less_than(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated_less_than", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match resource type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _MonitoredResourcesSearchState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 exclude_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 host_name_contains: Optional[pulumi.Input[str]] = None,
                 items: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchItemArgs']]]] = None,
                 management_agent_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_contains: Optional[pulumi.Input[str]] = None,
                 property_equals: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 resource_time_zone: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_created_less_than: Optional[pulumi.Input[str]] = None,
                 time_updated_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_updated_less_than: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MonitoredResourcesSearch resources.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] exclude_fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] external_id: External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] host_name: A filter to return resources with host name match.
        :param pulumi.Input[str] host_name_contains: A filter to return resources with host name pattern.
        :param pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchItemArgs']]] items: List of monitored resources.
        :param pulumi.Input[str] management_agent_id: A filter to return resources with matching management agent id.
        :param pulumi.Input[str] name: A filter to return resources that match exact resource name.
        :param pulumi.Input[str] name_contains: A filter to return resources that match resource name pattern given. The match is not case sensitive.
        :param pulumi.Input[Mapping[str, Any]] property_equals: Criteria based on resource property.
        :param pulumi.Input[str] resource_time_zone: Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        :param pulumi.Input[str] state: A filter to return resources with matching lifecycle state.
        :param pulumi.Input[str] time_created_greater_than_or_equal_to: Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_created_less_than: Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_greater_than_or_equal_to: Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_less_than: Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] type: A filter to return resources that match resource type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if exclude_fields is not None:
            pulumi.set(__self__, "exclude_fields", exclude_fields)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if fields is not None:
            pulumi.set(__self__, "fields", fields)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if host_name_contains is not None:
            pulumi.set(__self__, "host_name_contains", host_name_contains)
        if items is not None:
            pulumi.set(__self__, "items", items)
        if management_agent_id is not None:
            pulumi.set(__self__, "management_agent_id", management_agent_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if name_contains is not None:
            pulumi.set(__self__, "name_contains", name_contains)
        if property_equals is not None:
            pulumi.set(__self__, "property_equals", property_equals)
        if resource_time_zone is not None:
            pulumi.set(__self__, "resource_time_zone", resource_time_zone)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created_greater_than_or_equal_to is not None:
            pulumi.set(__self__, "time_created_greater_than_or_equal_to", time_created_greater_than_or_equal_to)
        if time_created_less_than is not None:
            pulumi.set(__self__, "time_created_less_than", time_created_less_than)
        if time_updated_greater_than_or_equal_to is not None:
            pulumi.set(__self__, "time_updated_greater_than_or_equal_to", time_updated_greater_than_or_equal_to)
        if time_updated_less_than is not None:
            pulumi.set(__self__, "time_updated_less_than", time_updated_less_than)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="excludeFields")
    def exclude_fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "exclude_fields")

    @exclude_fields.setter
    def exclude_fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "exclude_fields", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "fields")

    @fields.setter
    def fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "fields", value)

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with host name match.
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name", value)

    @property
    @pulumi.getter(name="hostNameContains")
    def host_name_contains(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with host name pattern.
        """
        return pulumi.get(self, "host_name_contains")

    @host_name_contains.setter
    def host_name_contains(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_name_contains", value)

    @property
    @pulumi.getter
    def items(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchItemArgs']]]]:
        """
        List of monitored resources.
        """
        return pulumi.get(self, "items")

    @items.setter
    def items(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchItemArgs']]]]):
        pulumi.set(self, "items", value)

    @property
    @pulumi.getter(name="managementAgentId")
    def management_agent_id(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with matching management agent id.
        """
        return pulumi.get(self, "management_agent_id")

    @management_agent_id.setter
    def management_agent_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "management_agent_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match exact resource name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match resource name pattern given. The match is not case sensitive.
        """
        return pulumi.get(self, "name_contains")

    @name_contains.setter
    def name_contains(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_contains", value)

    @property
    @pulumi.getter(name="propertyEquals")
    def property_equals(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Criteria based on resource property.
        """
        return pulumi.get(self, "property_equals")

    @property_equals.setter
    def property_equals(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "property_equals", value)

    @property
    @pulumi.getter(name="resourceTimeZone")
    def resource_time_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        """
        return pulumi.get(self, "resource_time_zone")

    @resource_time_zone.setter
    def resource_time_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_time_zone", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources with matching lifecycle state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreatedGreaterThanOrEqualTo")
    def time_created_greater_than_or_equal_to(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_greater_than_or_equal_to")

    @time_created_greater_than_or_equal_to.setter
    def time_created_greater_than_or_equal_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created_greater_than_or_equal_to", value)

    @property
    @pulumi.getter(name="timeCreatedLessThan")
    def time_created_less_than(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_less_than")

    @time_created_less_than.setter
    def time_created_less_than(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created_less_than", value)

    @property
    @pulumi.getter(name="timeUpdatedGreaterThanOrEqualTo")
    def time_updated_greater_than_or_equal_to(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_greater_than_or_equal_to")

    @time_updated_greater_than_or_equal_to.setter
    def time_updated_greater_than_or_equal_to(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated_greater_than_or_equal_to", value)

    @property
    @pulumi.getter(name="timeUpdatedLessThan")
    def time_updated_less_than(self) -> Optional[pulumi.Input[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_less_than")

    @time_updated_less_than.setter
    def time_updated_less_than(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated_less_than", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        A filter to return resources that match resource type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class MonitoredResourcesSearch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 exclude_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 host_name_contains: Optional[pulumi.Input[str]] = None,
                 management_agent_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_contains: Optional[pulumi.Input[str]] = None,
                 property_equals: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 resource_time_zone: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_created_less_than: Optional[pulumi.Input[str]] = None,
                 time_updated_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_updated_less_than: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Monitored Resources Search resource in Oracle Cloud Infrastructure Stack Monitoring service.

        Gets a list of all monitored resources in a compartment for the given search criteria.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_search = oci.stack_monitoring.MonitoredResourcesSearch("testMonitoredResourcesSearch",
            compartment_id=var["compartment_id"],
            exclude_fields=var["monitored_resources_search_exclude_fields"],
            external_id=oci_stack_monitoring_external["test_external"]["id"],
            fields=var["monitored_resources_search_fields"],
            host_name=var["monitored_resources_search_host_name"],
            host_name_contains=var["monitored_resources_search_host_name_contains"],
            management_agent_id=oci_management_agent_management_agent["test_management_agent"]["id"],
            name_contains=var["monitored_resources_search_name_contains"],
            property_equals=var["monitored_resources_search_property_equals"],
            resource_time_zone=var["monitored_resources_search_resource_time_zone"],
            state=var["monitored_resources_search_state"],
            time_created_greater_than_or_equal_to=var["monitored_resources_search_time_created_greater_than_or_equal_to"],
            time_created_less_than=var["monitored_resources_search_time_created_less_than"],
            time_updated_greater_than_or_equal_to=var["monitored_resources_search_time_updated_greater_than_or_equal_to"],
            time_updated_less_than=var["monitored_resources_search_time_updated_less_than"],
            type=var["monitored_resources_search_type"])
        ```

        ## Import

        MonitoredResourcesSearch can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesSearch:MonitoredResourcesSearch test_monitored_resources_search "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] exclude_fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] external_id: External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] host_name: A filter to return resources with host name match.
        :param pulumi.Input[str] host_name_contains: A filter to return resources with host name pattern.
        :param pulumi.Input[str] management_agent_id: A filter to return resources with matching management agent id.
        :param pulumi.Input[str] name: A filter to return resources that match exact resource name.
        :param pulumi.Input[str] name_contains: A filter to return resources that match resource name pattern given. The match is not case sensitive.
        :param pulumi.Input[Mapping[str, Any]] property_equals: Criteria based on resource property.
        :param pulumi.Input[str] resource_time_zone: Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        :param pulumi.Input[str] state: A filter to return resources with matching lifecycle state.
        :param pulumi.Input[str] time_created_greater_than_or_equal_to: Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_created_less_than: Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_greater_than_or_equal_to: Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_less_than: Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] type: A filter to return resources that match resource type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitoredResourcesSearchArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Monitored Resources Search resource in Oracle Cloud Infrastructure Stack Monitoring service.

        Gets a list of all monitored resources in a compartment for the given search criteria.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_search = oci.stack_monitoring.MonitoredResourcesSearch("testMonitoredResourcesSearch",
            compartment_id=var["compartment_id"],
            exclude_fields=var["monitored_resources_search_exclude_fields"],
            external_id=oci_stack_monitoring_external["test_external"]["id"],
            fields=var["monitored_resources_search_fields"],
            host_name=var["monitored_resources_search_host_name"],
            host_name_contains=var["monitored_resources_search_host_name_contains"],
            management_agent_id=oci_management_agent_management_agent["test_management_agent"]["id"],
            name_contains=var["monitored_resources_search_name_contains"],
            property_equals=var["monitored_resources_search_property_equals"],
            resource_time_zone=var["monitored_resources_search_resource_time_zone"],
            state=var["monitored_resources_search_state"],
            time_created_greater_than_or_equal_to=var["monitored_resources_search_time_created_greater_than_or_equal_to"],
            time_created_less_than=var["monitored_resources_search_time_created_less_than"],
            time_updated_greater_than_or_equal_to=var["monitored_resources_search_time_updated_greater_than_or_equal_to"],
            time_updated_less_than=var["monitored_resources_search_time_updated_less_than"],
            type=var["monitored_resources_search_type"])
        ```

        ## Import

        MonitoredResourcesSearch can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesSearch:MonitoredResourcesSearch test_monitored_resources_search "id"
        ```

        :param str resource_name: The name of the resource.
        :param MonitoredResourcesSearchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitoredResourcesSearchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 exclude_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 host_name: Optional[pulumi.Input[str]] = None,
                 host_name_contains: Optional[pulumi.Input[str]] = None,
                 management_agent_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 name_contains: Optional[pulumi.Input[str]] = None,
                 property_equals: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 resource_time_zone: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_created_less_than: Optional[pulumi.Input[str]] = None,
                 time_updated_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
                 time_updated_less_than: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitoredResourcesSearchArgs.__new__(MonitoredResourcesSearchArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["exclude_fields"] = exclude_fields
            __props__.__dict__["external_id"] = external_id
            __props__.__dict__["fields"] = fields
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["host_name_contains"] = host_name_contains
            __props__.__dict__["management_agent_id"] = management_agent_id
            __props__.__dict__["name"] = name
            __props__.__dict__["name_contains"] = name_contains
            __props__.__dict__["property_equals"] = property_equals
            __props__.__dict__["resource_time_zone"] = resource_time_zone
            __props__.__dict__["state"] = state
            __props__.__dict__["time_created_greater_than_or_equal_to"] = time_created_greater_than_or_equal_to
            __props__.__dict__["time_created_less_than"] = time_created_less_than
            __props__.__dict__["time_updated_greater_than_or_equal_to"] = time_updated_greater_than_or_equal_to
            __props__.__dict__["time_updated_less_than"] = time_updated_less_than
            __props__.__dict__["type"] = type
            __props__.__dict__["items"] = None
        super(MonitoredResourcesSearch, __self__).__init__(
            'oci:StackMonitoring/monitoredResourcesSearch:MonitoredResourcesSearch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            exclude_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            host_name: Optional[pulumi.Input[str]] = None,
            host_name_contains: Optional[pulumi.Input[str]] = None,
            items: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesSearchItemArgs']]]]] = None,
            management_agent_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            name_contains: Optional[pulumi.Input[str]] = None,
            property_equals: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            resource_time_zone: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
            time_created_less_than: Optional[pulumi.Input[str]] = None,
            time_updated_greater_than_or_equal_to: Optional[pulumi.Input[str]] = None,
            time_updated_less_than: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'MonitoredResourcesSearch':
        """
        Get an existing MonitoredResourcesSearch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] exclude_fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] external_id: External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] fields: Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        :param pulumi.Input[str] host_name: A filter to return resources with host name match.
        :param pulumi.Input[str] host_name_contains: A filter to return resources with host name pattern.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesSearchItemArgs']]]] items: List of monitored resources.
        :param pulumi.Input[str] management_agent_id: A filter to return resources with matching management agent id.
        :param pulumi.Input[str] name: A filter to return resources that match exact resource name.
        :param pulumi.Input[str] name_contains: A filter to return resources that match resource name pattern given. The match is not case sensitive.
        :param pulumi.Input[Mapping[str, Any]] property_equals: Criteria based on resource property.
        :param pulumi.Input[str] resource_time_zone: Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        :param pulumi.Input[str] state: A filter to return resources with matching lifecycle state.
        :param pulumi.Input[str] time_created_greater_than_or_equal_to: Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_created_less_than: Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_greater_than_or_equal_to: Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] time_updated_less_than: Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
               
               **Example:** 2016-12-19T16:39:57.600Z
        :param pulumi.Input[str] type: A filter to return resources that match resource type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitoredResourcesSearchState.__new__(_MonitoredResourcesSearchState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["exclude_fields"] = exclude_fields
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["fields"] = fields
        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["host_name_contains"] = host_name_contains
        __props__.__dict__["items"] = items
        __props__.__dict__["management_agent_id"] = management_agent_id
        __props__.__dict__["name"] = name
        __props__.__dict__["name_contains"] = name_contains
        __props__.__dict__["property_equals"] = property_equals
        __props__.__dict__["resource_time_zone"] = resource_time_zone
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created_greater_than_or_equal_to"] = time_created_greater_than_or_equal_to
        __props__.__dict__["time_created_less_than"] = time_created_less_than
        __props__.__dict__["time_updated_greater_than_or_equal_to"] = time_updated_greater_than_or_equal_to
        __props__.__dict__["time_updated_less_than"] = time_updated_less_than
        __props__.__dict__["type"] = type
        return MonitoredResourcesSearch(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="excludeFields")
    def exclude_fields(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return all the information except the fields requested to be excluded (excludeFields) by the client. In this mechanism, the client sends the exclude field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to exlude and to return and should be a query string parameter called "excludeFields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "exclude_fields")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[Optional[str]]:
        """
        External resource is any Oracle Cloud Infrastructure resource identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) which is not a Stack Monitoring service resource. Currently supports only following resource types - Container database, non-container database,  pluggable database and Oracle Cloud Infrastructure compute instance.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def fields(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Partial response refers to an optimization technique offered by the RESTful web APIs, to return only the information (fields) required by the client. In this mechanism, the client sends the required field names as the query parameters for an API to the server, and the server trims down the default response content by removing the fields that are not required by the client. The parameter controls which fields to return and should be a query string parameter called "fields" of an array type, provide the values as enums, and use collectionFormat.
        """
        return pulumi.get(self, "fields")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources with host name match.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hostNameContains")
    def host_name_contains(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources with host name pattern.
        """
        return pulumi.get(self, "host_name_contains")

    @property
    @pulumi.getter
    def items(self) -> pulumi.Output[Sequence['outputs.MonitoredResourcesSearchItem']]:
        """
        List of monitored resources.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="managementAgentId")
    def management_agent_id(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources with matching management agent id.
        """
        return pulumi.get(self, "management_agent_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A filter to return resources that match exact resource name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources that match resource name pattern given. The match is not case sensitive.
        """
        return pulumi.get(self, "name_contains")

    @property
    @pulumi.getter(name="propertyEquals")
    def property_equals(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        Criteria based on resource property.
        """
        return pulumi.get(self, "property_equals")

    @property
    @pulumi.getter(name="resourceTimeZone")
    def resource_time_zone(self) -> pulumi.Output[Optional[str]]:
        """
        Time zone in the form of tz database canonical zone ID. Specifies the preference with a value that uses the IANA Time Zone Database format (x-obmcs-time-zone). For example - America/Los_Angeles
        """
        return pulumi.get(self, "resource_time_zone")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources with matching lifecycle state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreatedGreaterThanOrEqualTo")
    def time_created_greater_than_or_equal_to(self) -> pulumi.Output[Optional[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the earliest creation date for the returned list (inclusive). Specifying this parameter without the corresponding `timeCreatedLessThan` parameter will retrieve resources created from the given `timeCreatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeCreatedLessThan")
    def time_created_less_than(self) -> pulumi.Output[Optional[str]]:
        """
        Search for resources that were created within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeCreatedGreaterThanOrEqualTo` parameter will retrieve all resources created before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_created_less_than")

    @property
    @pulumi.getter(name="timeUpdatedGreaterThanOrEqualTo")
    def time_updated_greater_than_or_equal_to(self) -> pulumi.Output[Optional[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the earliest update date for the returned list (inclusive). Specifying this parameter without the corresponding `timeUpdatedLessThan` parameter will retrieve resources updated from the given `timeUpdatedGreaterThanOrEqualTo` to the current time, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeUpdatedLessThan")
    def time_updated_less_than(self) -> pulumi.Output[Optional[str]]:
        """
        Search for resources that were updated within a specific date range, using this parameter to specify the latest creation date for the returned list (exclusive). Specifying this parameter without the corresponding `timeUpdatedGreaterThanOrEqualTo` parameter will retrieve all resources updated before the specified end date, in "YYYY-MM-ddThh:mmZ" format with a Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).

        **Example:** 2016-12-19T16:39:57.600Z
        """
        return pulumi.get(self, "time_updated_less_than")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[str]]:
        """
        A filter to return resources that match resource type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetPbfListingVersionResult',
    'AwaitableGetPbfListingVersionResult',
    'get_pbf_listing_version',
    'get_pbf_listing_version_output',
]

@pulumi.output_type
class GetPbfListingVersionResult:
    """
    A collection of values returned by getPbfListingVersion.
    """
    def __init__(__self__, change_summary=None, configs=None, defined_tags=None, freeform_tags=None, id=None, name=None, pbf_listing_id=None, pbf_listing_version_id=None, requirements=None, state=None, system_tags=None, time_created=None, time_updated=None, triggers=None):
        if change_summary and not isinstance(change_summary, str):
            raise TypeError("Expected argument 'change_summary' to be a str")
        pulumi.set(__self__, "change_summary", change_summary)
        if configs and not isinstance(configs, list):
            raise TypeError("Expected argument 'configs' to be a list")
        pulumi.set(__self__, "configs", configs)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if pbf_listing_id and not isinstance(pbf_listing_id, str):
            raise TypeError("Expected argument 'pbf_listing_id' to be a str")
        pulumi.set(__self__, "pbf_listing_id", pbf_listing_id)
        if pbf_listing_version_id and not isinstance(pbf_listing_version_id, str):
            raise TypeError("Expected argument 'pbf_listing_version_id' to be a str")
        pulumi.set(__self__, "pbf_listing_version_id", pbf_listing_version_id)
        if requirements and not isinstance(requirements, list):
            raise TypeError("Expected argument 'requirements' to be a list")
        pulumi.set(__self__, "requirements", requirements)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if triggers and not isinstance(triggers, list):
            raise TypeError("Expected argument 'triggers' to be a list")
        pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter(name="changeSummary")
    def change_summary(self) -> str:
        """
        Details changes are included in this version.
        """
        return pulumi.get(self, "change_summary")

    @property
    @pulumi.getter
    def configs(self) -> Sequence['outputs.GetPbfListingVersionConfigResult']:
        """
        Details about the required and optional Function configurations needed for proper performance of the PBF.
        """
        return pulumi.get(self, "configs")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A brief descriptive name for the PBF trigger.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="pbfListingId")
    def pbf_listing_id(self) -> str:
        """
        The OCID of the PbfListing this resource version belongs to.
        """
        return pulumi.get(self, "pbf_listing_id")

    @property
    @pulumi.getter(name="pbfListingVersionId")
    def pbf_listing_version_id(self) -> str:
        return pulumi.get(self, "pbf_listing_version_id")

    @property
    @pulumi.getter
    def requirements(self) -> Sequence['outputs.GetPbfListingVersionRequirementResult']:
        """
        Minimum memory required by this PBF. The user should use memory greater than or equal to this value  while configuring the Function.
        """
        return pulumi.get(self, "requirements")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the PBF resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the PbfListingVersion was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The last time the PbfListingVersion was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def triggers(self) -> Sequence['outputs.GetPbfListingVersionTriggerResult']:
        """
        An array of Trigger. A list of triggers that may activate the PBF.
        """
        return pulumi.get(self, "triggers")


class AwaitableGetPbfListingVersionResult(GetPbfListingVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPbfListingVersionResult(
            change_summary=self.change_summary,
            configs=self.configs,
            defined_tags=self.defined_tags,
            freeform_tags=self.freeform_tags,
            id=self.id,
            name=self.name,
            pbf_listing_id=self.pbf_listing_id,
            pbf_listing_version_id=self.pbf_listing_version_id,
            requirements=self.requirements,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated,
            triggers=self.triggers)


def get_pbf_listing_version(pbf_listing_version_id: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPbfListingVersionResult:
    """
    This data source provides details about a specific Pbf Listing Version resource in Oracle Cloud Infrastructure Functions service.

    Gets a PbfListingVersion by identifier for a PbfListing.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_pbf_listing_version = oci.Functions.get_pbf_listing_version(pbf_listing_version_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str pbf_listing_version_id: unique PbfListingVersion identifier
    """
    __args__ = dict()
    __args__['pbfListingVersionId'] = pbf_listing_version_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getPbfListingVersion:getPbfListingVersion', __args__, opts=opts, typ=GetPbfListingVersionResult).value

    return AwaitableGetPbfListingVersionResult(
        change_summary=__ret__.change_summary,
        configs=__ret__.configs,
        defined_tags=__ret__.defined_tags,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        name=__ret__.name,
        pbf_listing_id=__ret__.pbf_listing_id,
        pbf_listing_version_id=__ret__.pbf_listing_version_id,
        requirements=__ret__.requirements,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated,
        triggers=__ret__.triggers)


@_utilities.lift_output_func(get_pbf_listing_version)
def get_pbf_listing_version_output(pbf_listing_version_id: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPbfListingVersionResult]:
    """
    This data source provides details about a specific Pbf Listing Version resource in Oracle Cloud Infrastructure Functions service.

    Gets a PbfListingVersion by identifier for a PbfListing.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_pbf_listing_version = oci.Functions.get_pbf_listing_version(pbf_listing_version_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str pbf_listing_version_id: unique PbfListingVersion identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetGenericArtifactsContentResult',
    'AwaitableGetGenericArtifactsContentResult',
    'get_generic_artifacts_content',
    'get_generic_artifacts_content_output',
]

@pulumi.output_type
class GetGenericArtifactsContentResult:
    """
    A collection of values returned by getGenericArtifactsContent.
    """
    def __init__(__self__, artifact_id=None, id=None):
        if artifact_id and not isinstance(artifact_id, str):
            raise TypeError("Expected argument 'artifact_id' to be a str")
        pulumi.set(__self__, "artifact_id", artifact_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="artifactId")
    def artifact_id(self) -> str:
        return pulumi.get(self, "artifact_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetGenericArtifactsContentResult(GetGenericArtifactsContentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGenericArtifactsContentResult(
            artifact_id=self.artifact_id,
            id=self.id)


def get_generic_artifacts_content(artifact_id: Optional[str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGenericArtifactsContentResult:
    """
    This data source provides details about a specific Generic Artifacts Content resource in Oracle Cloud Infrastructure Generic Artifacts Content service.

    Gets the specified artifact's content.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_generic_artifacts_content = oci.GenericArtifactsContent.get_generic_artifacts_content(artifact_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str artifact_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the artifact.  Example: `ocid1.genericartifact.oc1..exampleuniqueID`
    """
    __args__ = dict()
    __args__['artifactId'] = artifact_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:GenericArtifactsContent/getGenericArtifactsContent:getGenericArtifactsContent', __args__, opts=opts, typ=GetGenericArtifactsContentResult).value

    return AwaitableGetGenericArtifactsContentResult(
        artifact_id=__ret__.artifact_id,
        id=__ret__.id)


@_utilities.lift_output_func(get_generic_artifacts_content)
def get_generic_artifacts_content_output(artifact_id: Optional[pulumi.Input[str]] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGenericArtifactsContentResult]:
    """
    This data source provides details about a specific Generic Artifacts Content resource in Oracle Cloud Infrastructure Generic Artifacts Content service.

    Gets the specified artifact's content.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_generic_artifacts_content = oci.GenericArtifactsContent.get_generic_artifacts_content(artifact_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str artifact_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the artifact.  Example: `ocid1.genericartifact.oc1..exampleuniqueID`
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCloudAutonomousVmClustersResult',
    'AwaitableGetCloudAutonomousVmClustersResult',
    'get_cloud_autonomous_vm_clusters',
    'get_cloud_autonomous_vm_clusters_output',
]

@pulumi.output_type
class GetCloudAutonomousVmClustersResult:
    """
    A collection of values returned by getCloudAutonomousVmClusters.
    """
    def __init__(__self__, availability_domain=None, cloud_autonomous_vm_clusters=None, cloud_exadata_infrastructure_id=None, compartment_id=None, display_name=None, filters=None, id=None, state=None):
        if availability_domain and not isinstance(availability_domain, str):
            raise TypeError("Expected argument 'availability_domain' to be a str")
        pulumi.set(__self__, "availability_domain", availability_domain)
        if cloud_autonomous_vm_clusters and not isinstance(cloud_autonomous_vm_clusters, list):
            raise TypeError("Expected argument 'cloud_autonomous_vm_clusters' to be a list")
        pulumi.set(__self__, "cloud_autonomous_vm_clusters", cloud_autonomous_vm_clusters)
        if cloud_exadata_infrastructure_id and not isinstance(cloud_exadata_infrastructure_id, str):
            raise TypeError("Expected argument 'cloud_exadata_infrastructure_id' to be a str")
        pulumi.set(__self__, "cloud_exadata_infrastructure_id", cloud_exadata_infrastructure_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> Optional[str]:
        """
        The name of the availability domain that the cloud Autonomous VM cluster is located in.
        """
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="cloudAutonomousVmClusters")
    def cloud_autonomous_vm_clusters(self) -> Sequence['outputs.GetCloudAutonomousVmClustersCloudAutonomousVmClusterResult']:
        """
        The list of cloud_autonomous_vm_clusters.
        """
        return pulumi.get(self, "cloud_autonomous_vm_clusters")

    @property
    @pulumi.getter(name="cloudExadataInfrastructureId")
    def cloud_exadata_infrastructure_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
        """
        return pulumi.get(self, "cloud_exadata_infrastructure_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetCloudAutonomousVmClustersFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the cloud Autonomous VM cluster.
        """
        return pulumi.get(self, "state")


class AwaitableGetCloudAutonomousVmClustersResult(GetCloudAutonomousVmClustersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudAutonomousVmClustersResult(
            availability_domain=self.availability_domain,
            cloud_autonomous_vm_clusters=self.cloud_autonomous_vm_clusters,
            cloud_exadata_infrastructure_id=self.cloud_exadata_infrastructure_id,
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            state=self.state)


def get_cloud_autonomous_vm_clusters(availability_domain: Optional[str] = None,
                                     cloud_exadata_infrastructure_id: Optional[str] = None,
                                     compartment_id: Optional[str] = None,
                                     display_name: Optional[str] = None,
                                     filters: Optional[Sequence[pulumi.InputType['GetCloudAutonomousVmClustersFilterArgs']]] = None,
                                     state: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudAutonomousVmClustersResult:
    """
    This data source provides the list of Cloud Autonomous Vm Clusters in Oracle Cloud Infrastructure Database service.

    Lists Autonomous Exadata VM clusters in the Oracle cloud. For Exadata Cloud@Customer systems, see [ListAutonomousVmClusters](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/AutonomousVmCluster/ListAutonomousVmClusters).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cloud_autonomous_vm_clusters = oci.Database.get_cloud_autonomous_vm_clusters(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        cloud_exadata_infrastructure_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str availability_domain: A filter to return only resources that match the given availability domain exactly.
    :param str cloud_exadata_infrastructure_id: If provided, filters the results for the specified cloud Exadata infrastructure.
    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only resources that match the entire display name given. The match is not case sensitive.
    :param str state: A filter to return only resources that match the given lifecycle state exactly.
    """
    __args__ = dict()
    __args__['availabilityDomain'] = availability_domain
    __args__['cloudExadataInfrastructureId'] = cloud_exadata_infrastructure_id
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getCloudAutonomousVmClusters:getCloudAutonomousVmClusters', __args__, opts=opts, typ=GetCloudAutonomousVmClustersResult).value

    return AwaitableGetCloudAutonomousVmClustersResult(
        availability_domain=__ret__.availability_domain,
        cloud_autonomous_vm_clusters=__ret__.cloud_autonomous_vm_clusters,
        cloud_exadata_infrastructure_id=__ret__.cloud_exadata_infrastructure_id,
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state)


@_utilities.lift_output_func(get_cloud_autonomous_vm_clusters)
def get_cloud_autonomous_vm_clusters_output(availability_domain: Optional[pulumi.Input[Optional[str]]] = None,
                                            cloud_exadata_infrastructure_id: Optional[pulumi.Input[Optional[str]]] = None,
                                            compartment_id: Optional[pulumi.Input[str]] = None,
                                            display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                            filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetCloudAutonomousVmClustersFilterArgs']]]]] = None,
                                            state: Optional[pulumi.Input[Optional[str]]] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCloudAutonomousVmClustersResult]:
    """
    This data source provides the list of Cloud Autonomous Vm Clusters in Oracle Cloud Infrastructure Database service.

    Lists Autonomous Exadata VM clusters in the Oracle cloud. For Exadata Cloud@Customer systems, see [ListAutonomousVmClusters](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/AutonomousVmCluster/ListAutonomousVmClusters).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cloud_autonomous_vm_clusters = oci.Database.get_cloud_autonomous_vm_clusters(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        cloud_exadata_infrastructure_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str availability_domain: A filter to return only resources that match the given availability domain exactly.
    :param str cloud_exadata_infrastructure_id: If provided, filters the results for the specified cloud Exadata infrastructure.
    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str display_name: A filter to return only resources that match the entire display name given. The match is not case sensitive.
    :param str state: A filter to return only resources that match the given lifecycle state exactly.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SessionArgs', 'Session']

@pulumi.input_type
class SessionArgs:
    def __init__(__self__, *,
                 bastion_id: pulumi.Input[str],
                 key_details: pulumi.Input['SessionKeyDetailsArgs'],
                 target_resource_details: pulumi.Input['SessionTargetResourceDetailsArgs'],
                 display_name: Optional[pulumi.Input[str]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 session_ttl_in_seconds: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Session resource.
        :param pulumi.Input[str] bastion_id: The unique identifier (OCID) of the bastion on which to create this session.
        :param pulumi.Input['SessionKeyDetailsArgs'] key_details: Public key details for a bastion session.
        :param pulumi.Input['SessionTargetResourceDetailsArgs'] target_resource_details: Details about a bastion session's target resource.
        :param pulumi.Input[str] display_name: (Updatable) The name of the session.
        :param pulumi.Input[str] key_type: The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        :param pulumi.Input[int] session_ttl_in_seconds: The amount of time the session can remain active.
        """
        pulumi.set(__self__, "bastion_id", bastion_id)
        pulumi.set(__self__, "key_details", key_details)
        pulumi.set(__self__, "target_resource_details", target_resource_details)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if key_type is not None:
            pulumi.set(__self__, "key_type", key_type)
        if session_ttl_in_seconds is not None:
            pulumi.set(__self__, "session_ttl_in_seconds", session_ttl_in_seconds)

    @property
    @pulumi.getter(name="bastionId")
    def bastion_id(self) -> pulumi.Input[str]:
        """
        The unique identifier (OCID) of the bastion on which to create this session.
        """
        return pulumi.get(self, "bastion_id")

    @bastion_id.setter
    def bastion_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "bastion_id", value)

    @property
    @pulumi.getter(name="keyDetails")
    def key_details(self) -> pulumi.Input['SessionKeyDetailsArgs']:
        """
        Public key details for a bastion session.
        """
        return pulumi.get(self, "key_details")

    @key_details.setter
    def key_details(self, value: pulumi.Input['SessionKeyDetailsArgs']):
        pulumi.set(self, "key_details", value)

    @property
    @pulumi.getter(name="targetResourceDetails")
    def target_resource_details(self) -> pulumi.Input['SessionTargetResourceDetailsArgs']:
        """
        Details about a bastion session's target resource.
        """
        return pulumi.get(self, "target_resource_details")

    @target_resource_details.setter
    def target_resource_details(self, value: pulumi.Input['SessionTargetResourceDetailsArgs']):
        pulumi.set(self, "target_resource_details", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The name of the session.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="keyType")
    def key_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        """
        return pulumi.get(self, "key_type")

    @key_type.setter
    def key_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_type", value)

    @property
    @pulumi.getter(name="sessionTtlInSeconds")
    def session_ttl_in_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of time the session can remain active.
        """
        return pulumi.get(self, "session_ttl_in_seconds")

    @session_ttl_in_seconds.setter
    def session_ttl_in_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "session_ttl_in_seconds", value)


@pulumi.input_type
class _SessionState:
    def __init__(__self__, *,
                 bastion_id: Optional[pulumi.Input[str]] = None,
                 bastion_name: Optional[pulumi.Input[str]] = None,
                 bastion_public_host_key_info: Optional[pulumi.Input[str]] = None,
                 bastion_user_name: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 key_details: Optional[pulumi.Input['SessionKeyDetailsArgs']] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 session_ttl_in_seconds: Optional[pulumi.Input[int]] = None,
                 ssh_metadata: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 target_resource_details: Optional[pulumi.Input['SessionTargetResourceDetailsArgs']] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Session resources.
        :param pulumi.Input[str] bastion_id: The unique identifier (OCID) of the bastion on which to create this session.
        :param pulumi.Input[str] bastion_name: The name of the bastion that is hosting this session.
        :param pulumi.Input[str] bastion_public_host_key_info: The public key of the bastion host. You can use this to verify that you're connecting to the correct bastion.
        :param pulumi.Input[str] bastion_user_name: The username that the session uses to connect to the target resource.
        :param pulumi.Input[str] display_name: (Updatable) The name of the session.
        :param pulumi.Input['SessionKeyDetailsArgs'] key_details: Public key details for a bastion session.
        :param pulumi.Input[str] key_type: The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        :param pulumi.Input[str] lifecycle_details: A message describing the current session state in more detail.
        :param pulumi.Input[int] session_ttl_in_seconds: The amount of time the session can remain active.
        :param pulumi.Input[Mapping[str, Any]] ssh_metadata: The connection message for the session.
        :param pulumi.Input[str] state: The current state of the session.
        :param pulumi.Input['SessionTargetResourceDetailsArgs'] target_resource_details: Details about a bastion session's target resource.
        :param pulumi.Input[str] time_created: The time the session was created. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        :param pulumi.Input[str] time_updated: The time the session was updated. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        if bastion_id is not None:
            pulumi.set(__self__, "bastion_id", bastion_id)
        if bastion_name is not None:
            pulumi.set(__self__, "bastion_name", bastion_name)
        if bastion_public_host_key_info is not None:
            pulumi.set(__self__, "bastion_public_host_key_info", bastion_public_host_key_info)
        if bastion_user_name is not None:
            pulumi.set(__self__, "bastion_user_name", bastion_user_name)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if key_details is not None:
            pulumi.set(__self__, "key_details", key_details)
        if key_type is not None:
            pulumi.set(__self__, "key_type", key_type)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if session_ttl_in_seconds is not None:
            pulumi.set(__self__, "session_ttl_in_seconds", session_ttl_in_seconds)
        if ssh_metadata is not None:
            pulumi.set(__self__, "ssh_metadata", ssh_metadata)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if target_resource_details is not None:
            pulumi.set(__self__, "target_resource_details", target_resource_details)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="bastionId")
    def bastion_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier (OCID) of the bastion on which to create this session.
        """
        return pulumi.get(self, "bastion_id")

    @bastion_id.setter
    def bastion_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastion_id", value)

    @property
    @pulumi.getter(name="bastionName")
    def bastion_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the bastion that is hosting this session.
        """
        return pulumi.get(self, "bastion_name")

    @bastion_name.setter
    def bastion_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastion_name", value)

    @property
    @pulumi.getter(name="bastionPublicHostKeyInfo")
    def bastion_public_host_key_info(self) -> Optional[pulumi.Input[str]]:
        """
        The public key of the bastion host. You can use this to verify that you're connecting to the correct bastion.
        """
        return pulumi.get(self, "bastion_public_host_key_info")

    @bastion_public_host_key_info.setter
    def bastion_public_host_key_info(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastion_public_host_key_info", value)

    @property
    @pulumi.getter(name="bastionUserName")
    def bastion_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The username that the session uses to connect to the target resource.
        """
        return pulumi.get(self, "bastion_user_name")

    @bastion_user_name.setter
    def bastion_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastion_user_name", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The name of the session.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="keyDetails")
    def key_details(self) -> Optional[pulumi.Input['SessionKeyDetailsArgs']]:
        """
        Public key details for a bastion session.
        """
        return pulumi.get(self, "key_details")

    @key_details.setter
    def key_details(self, value: Optional[pulumi.Input['SessionKeyDetailsArgs']]):
        pulumi.set(self, "key_details", value)

    @property
    @pulumi.getter(name="keyType")
    def key_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        """
        return pulumi.get(self, "key_type")

    @key_type.setter
    def key_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_type", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current session state in more detail.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="sessionTtlInSeconds")
    def session_ttl_in_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of time the session can remain active.
        """
        return pulumi.get(self, "session_ttl_in_seconds")

    @session_ttl_in_seconds.setter
    def session_ttl_in_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "session_ttl_in_seconds", value)

    @property
    @pulumi.getter(name="sshMetadata")
    def ssh_metadata(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The connection message for the session.
        """
        return pulumi.get(self, "ssh_metadata")

    @ssh_metadata.setter
    def ssh_metadata(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "ssh_metadata", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the session.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="targetResourceDetails")
    def target_resource_details(self) -> Optional[pulumi.Input['SessionTargetResourceDetailsArgs']]:
        """
        Details about a bastion session's target resource.
        """
        return pulumi.get(self, "target_resource_details")

    @target_resource_details.setter
    def target_resource_details(self, value: Optional[pulumi.Input['SessionTargetResourceDetailsArgs']]):
        pulumi.set(self, "target_resource_details", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time the session was created. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time the session was updated. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class Session(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bastion_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 key_details: Optional[pulumi.Input[pulumi.InputType['SessionKeyDetailsArgs']]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 session_ttl_in_seconds: Optional[pulumi.Input[int]] = None,
                 target_resource_details: Optional[pulumi.Input[pulumi.InputType['SessionTargetResourceDetailsArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Session resource in Oracle Cloud Infrastructure Bastion service.

        Creates a new session in a bastion. A bastion session lets authorized users connect to a target resource for a predetermined amount of time. The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_session = oci.bastion.Session("testSession",
            bastion_id=oci_bastion_bastion["test_bastion"]["id"],
            key_details=oci.bastion.SessionKeyDetailsArgs(
                public_key_content=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            target_resource_details=oci.bastion.SessionTargetResourceDetailsArgs(
                session_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_fqdn=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_operating_system_user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_private_ip_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            display_name=var["session_display_name"],
            key_type=var["session_key_type"],
            session_ttl_in_seconds=var["session_session_ttl_in_seconds"])
        ```

        ## Import

        Sessions can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Bastion/session:Session test_session "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bastion_id: The unique identifier (OCID) of the bastion on which to create this session.
        :param pulumi.Input[str] display_name: (Updatable) The name of the session.
        :param pulumi.Input[pulumi.InputType['SessionKeyDetailsArgs']] key_details: Public key details for a bastion session.
        :param pulumi.Input[str] key_type: The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        :param pulumi.Input[int] session_ttl_in_seconds: The amount of time the session can remain active.
        :param pulumi.Input[pulumi.InputType['SessionTargetResourceDetailsArgs']] target_resource_details: Details about a bastion session's target resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SessionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Session resource in Oracle Cloud Infrastructure Bastion service.

        Creates a new session in a bastion. A bastion session lets authorized users connect to a target resource for a predetermined amount of time. The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_session = oci.bastion.Session("testSession",
            bastion_id=oci_bastion_bastion["test_bastion"]["id"],
            key_details=oci.bastion.SessionKeyDetailsArgs(
                public_key_content=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            target_resource_details=oci.bastion.SessionTargetResourceDetailsArgs(
                session_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_fqdn=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_operating_system_user_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                target_resource_private_ip_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            display_name=var["session_display_name"],
            key_type=var["session_key_type"],
            session_ttl_in_seconds=var["session_session_ttl_in_seconds"])
        ```

        ## Import

        Sessions can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Bastion/session:Session test_session "id"
        ```

        :param str resource_name: The name of the resource.
        :param SessionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SessionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bastion_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 key_details: Optional[pulumi.Input[pulumi.InputType['SessionKeyDetailsArgs']]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 session_ttl_in_seconds: Optional[pulumi.Input[int]] = None,
                 target_resource_details: Optional[pulumi.Input[pulumi.InputType['SessionTargetResourceDetailsArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SessionArgs.__new__(SessionArgs)

            if bastion_id is None and not opts.urn:
                raise TypeError("Missing required property 'bastion_id'")
            __props__.__dict__["bastion_id"] = bastion_id
            __props__.__dict__["display_name"] = display_name
            if key_details is None and not opts.urn:
                raise TypeError("Missing required property 'key_details'")
            __props__.__dict__["key_details"] = key_details
            __props__.__dict__["key_type"] = key_type
            __props__.__dict__["session_ttl_in_seconds"] = session_ttl_in_seconds
            if target_resource_details is None and not opts.urn:
                raise TypeError("Missing required property 'target_resource_details'")
            __props__.__dict__["target_resource_details"] = target_resource_details
            __props__.__dict__["bastion_name"] = None
            __props__.__dict__["bastion_public_host_key_info"] = None
            __props__.__dict__["bastion_user_name"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["ssh_metadata"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(Session, __self__).__init__(
            'oci:Bastion/session:Session',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bastion_id: Optional[pulumi.Input[str]] = None,
            bastion_name: Optional[pulumi.Input[str]] = None,
            bastion_public_host_key_info: Optional[pulumi.Input[str]] = None,
            bastion_user_name: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            key_details: Optional[pulumi.Input[pulumi.InputType['SessionKeyDetailsArgs']]] = None,
            key_type: Optional[pulumi.Input[str]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            session_ttl_in_seconds: Optional[pulumi.Input[int]] = None,
            ssh_metadata: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            target_resource_details: Optional[pulumi.Input[pulumi.InputType['SessionTargetResourceDetailsArgs']]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'Session':
        """
        Get an existing Session resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bastion_id: The unique identifier (OCID) of the bastion on which to create this session.
        :param pulumi.Input[str] bastion_name: The name of the bastion that is hosting this session.
        :param pulumi.Input[str] bastion_public_host_key_info: The public key of the bastion host. You can use this to verify that you're connecting to the correct bastion.
        :param pulumi.Input[str] bastion_user_name: The username that the session uses to connect to the target resource.
        :param pulumi.Input[str] display_name: (Updatable) The name of the session.
        :param pulumi.Input[pulumi.InputType['SessionKeyDetailsArgs']] key_details: Public key details for a bastion session.
        :param pulumi.Input[str] key_type: The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        :param pulumi.Input[str] lifecycle_details: A message describing the current session state in more detail.
        :param pulumi.Input[int] session_ttl_in_seconds: The amount of time the session can remain active.
        :param pulumi.Input[Mapping[str, Any]] ssh_metadata: The connection message for the session.
        :param pulumi.Input[str] state: The current state of the session.
        :param pulumi.Input[pulumi.InputType['SessionTargetResourceDetailsArgs']] target_resource_details: Details about a bastion session's target resource.
        :param pulumi.Input[str] time_created: The time the session was created. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        :param pulumi.Input[str] time_updated: The time the session was updated. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SessionState.__new__(_SessionState)

        __props__.__dict__["bastion_id"] = bastion_id
        __props__.__dict__["bastion_name"] = bastion_name
        __props__.__dict__["bastion_public_host_key_info"] = bastion_public_host_key_info
        __props__.__dict__["bastion_user_name"] = bastion_user_name
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["key_details"] = key_details
        __props__.__dict__["key_type"] = key_type
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["session_ttl_in_seconds"] = session_ttl_in_seconds
        __props__.__dict__["ssh_metadata"] = ssh_metadata
        __props__.__dict__["state"] = state
        __props__.__dict__["target_resource_details"] = target_resource_details
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        return Session(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bastionId")
    def bastion_id(self) -> pulumi.Output[str]:
        """
        The unique identifier (OCID) of the bastion on which to create this session.
        """
        return pulumi.get(self, "bastion_id")

    @property
    @pulumi.getter(name="bastionName")
    def bastion_name(self) -> pulumi.Output[str]:
        """
        The name of the bastion that is hosting this session.
        """
        return pulumi.get(self, "bastion_name")

    @property
    @pulumi.getter(name="bastionPublicHostKeyInfo")
    def bastion_public_host_key_info(self) -> pulumi.Output[str]:
        """
        The public key of the bastion host. You can use this to verify that you're connecting to the correct bastion.
        """
        return pulumi.get(self, "bastion_public_host_key_info")

    @property
    @pulumi.getter(name="bastionUserName")
    def bastion_user_name(self) -> pulumi.Output[str]:
        """
        The username that the session uses to connect to the target resource.
        """
        return pulumi.get(self, "bastion_user_name")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The name of the session.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="keyDetails")
    def key_details(self) -> pulumi.Output['outputs.SessionKeyDetails']:
        """
        Public key details for a bastion session.
        """
        return pulumi.get(self, "key_details")

    @property
    @pulumi.getter(name="keyType")
    def key_type(self) -> pulumi.Output[str]:
        """
        The type of the key used to connect to the session. PUB is a standard public key in OpenSSH format.
        """
        return pulumi.get(self, "key_type")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current session state in more detail.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="sessionTtlInSeconds")
    def session_ttl_in_seconds(self) -> pulumi.Output[int]:
        """
        The amount of time the session can remain active.
        """
        return pulumi.get(self, "session_ttl_in_seconds")

    @property
    @pulumi.getter(name="sshMetadata")
    def ssh_metadata(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        The connection message for the session.
        """
        return pulumi.get(self, "ssh_metadata")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the session.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="targetResourceDetails")
    def target_resource_details(self) -> pulumi.Output['outputs.SessionTargetResourceDetails']:
        """
        Details about a bastion session's target resource.
        """
        return pulumi.get(self, "target_resource_details")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time the session was created. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time the session was updated. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'SddcDatastoreArgs',
    'SddcHcxOnPremLicenseArgs',
    'SddcUpgradeLicenseArgs',
    'SddcVsphereUpgradeObjectArgs',
    'GetExsiHostsFilterArgs',
    'GetSddcsFilterArgs',
    'GetSupportedHostShapesFilterArgs',
    'GetSupportedSkusFilterArgs',
    'GetSupportedVmwareSoftwareVersionsFilterArgs',
]

@pulumi.input_type
class SddcDatastoreArgs:
    def __init__(__self__, *,
                 block_volume_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 datastore_type: pulumi.Input[str],
                 capacity: Optional[pulumi.Input[float]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] block_volume_ids: A list of [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of Block Storage Volumes.
        :param pulumi.Input[str] datastore_type: Type of the datastore.
        :param pulumi.Input[float] capacity: Size of the Block Storage Volume in GB.
        """
        pulumi.set(__self__, "block_volume_ids", block_volume_ids)
        pulumi.set(__self__, "datastore_type", datastore_type)
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)

    @property
    @pulumi.getter(name="blockVolumeIds")
    def block_volume_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s of Block Storage Volumes.
        """
        return pulumi.get(self, "block_volume_ids")

    @block_volume_ids.setter
    def block_volume_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "block_volume_ids", value)

    @property
    @pulumi.getter(name="datastoreType")
    def datastore_type(self) -> pulumi.Input[str]:
        """
        Type of the datastore.
        """
        return pulumi.get(self, "datastore_type")

    @datastore_type.setter
    def datastore_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "datastore_type", value)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[float]]:
        """
        Size of the Block Storage Volume in GB.
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "capacity", value)


@pulumi.input_type
class SddcHcxOnPremLicenseArgs:
    def __init__(__self__, *,
                 activation_key: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 system_name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] activation_key: HCX on-premise license key value.
        :param pulumi.Input[str] status: status of HCX on-premise license.
        :param pulumi.Input[str] system_name: Name of the system that consumed the HCX on-premise license
        """
        if activation_key is not None:
            pulumi.set(__self__, "activation_key", activation_key)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if system_name is not None:
            pulumi.set(__self__, "system_name", system_name)

    @property
    @pulumi.getter(name="activationKey")
    def activation_key(self) -> Optional[pulumi.Input[str]]:
        """
        HCX on-premise license key value.
        """
        return pulumi.get(self, "activation_key")

    @activation_key.setter
    def activation_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "activation_key", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        status of HCX on-premise license.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="systemName")
    def system_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the system that consumed the HCX on-premise license
        """
        return pulumi.get(self, "system_name")

    @system_name.setter
    def system_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "system_name", value)


@pulumi.input_type
class SddcUpgradeLicenseArgs:
    def __init__(__self__, *,
                 license_key: Optional[pulumi.Input[str]] = None,
                 license_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] license_key: vSphere license key value.
        :param pulumi.Input[str] license_type: vSphere license type.
        """
        if license_key is not None:
            pulumi.set(__self__, "license_key", license_key)
        if license_type is not None:
            pulumi.set(__self__, "license_type", license_type)

    @property
    @pulumi.getter(name="licenseKey")
    def license_key(self) -> Optional[pulumi.Input[str]]:
        """
        vSphere license key value.
        """
        return pulumi.get(self, "license_key")

    @license_key.setter
    def license_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "license_key", value)

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> Optional[pulumi.Input[str]]:
        """
        vSphere license type.
        """
        return pulumi.get(self, "license_type")

    @license_type.setter
    def license_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "license_type", value)


@pulumi.input_type
class SddcVsphereUpgradeObjectArgs:
    def __init__(__self__, *,
                 download_link: Optional[pulumi.Input[str]] = None,
                 link_description: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] download_link: Binary object download link.
        :param pulumi.Input[str] link_description: Binary object description.
        """
        if download_link is not None:
            pulumi.set(__self__, "download_link", download_link)
        if link_description is not None:
            pulumi.set(__self__, "link_description", link_description)

    @property
    @pulumi.getter(name="downloadLink")
    def download_link(self) -> Optional[pulumi.Input[str]]:
        """
        Binary object download link.
        """
        return pulumi.get(self, "download_link")

    @download_link.setter
    def download_link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "download_link", value)

    @property
    @pulumi.getter(name="linkDescription")
    def link_description(self) -> Optional[pulumi.Input[str]]:
        """
        Binary object description.
        """
        return pulumi.get(self, "link_description")

    @link_description.setter
    def link_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "link_description", value)


@pulumi.input_type
class GetExsiHostsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSddcsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSupportedHostShapesFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: A filter to return only resources that match the given name exactly.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A filter to return only resources that match the given name exactly.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSupportedSkusFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: name of SKU
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        name of SKU
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSupportedVmwareSoftwareVersionsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetLetterOfAuthorityResult',
    'AwaitableGetLetterOfAuthorityResult',
    'get_letter_of_authority',
    'get_letter_of_authority_output',
]

@pulumi.output_type
class GetLetterOfAuthorityResult:
    """
    A collection of values returned by getLetterOfAuthority.
    """
    def __init__(__self__, authorized_entity_name=None, circuit_type=None, cross_connect_id=None, facility_location=None, id=None, port_name=None, time_expires=None, time_issued=None):
        if authorized_entity_name and not isinstance(authorized_entity_name, str):
            raise TypeError("Expected argument 'authorized_entity_name' to be a str")
        pulumi.set(__self__, "authorized_entity_name", authorized_entity_name)
        if circuit_type and not isinstance(circuit_type, str):
            raise TypeError("Expected argument 'circuit_type' to be a str")
        pulumi.set(__self__, "circuit_type", circuit_type)
        if cross_connect_id and not isinstance(cross_connect_id, str):
            raise TypeError("Expected argument 'cross_connect_id' to be a str")
        pulumi.set(__self__, "cross_connect_id", cross_connect_id)
        if facility_location and not isinstance(facility_location, str):
            raise TypeError("Expected argument 'facility_location' to be a str")
        pulumi.set(__self__, "facility_location", facility_location)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if port_name and not isinstance(port_name, str):
            raise TypeError("Expected argument 'port_name' to be a str")
        pulumi.set(__self__, "port_name", port_name)
        if time_expires and not isinstance(time_expires, str):
            raise TypeError("Expected argument 'time_expires' to be a str")
        pulumi.set(__self__, "time_expires", time_expires)
        if time_issued and not isinstance(time_issued, str):
            raise TypeError("Expected argument 'time_issued' to be a str")
        pulumi.set(__self__, "time_issued", time_issued)

    @property
    @pulumi.getter(name="authorizedEntityName")
    def authorized_entity_name(self) -> str:
        """
        The name of the entity authorized by this Letter of Authority.
        """
        return pulumi.get(self, "authorized_entity_name")

    @property
    @pulumi.getter(name="circuitType")
    def circuit_type(self) -> str:
        """
        The type of cross-connect fiber, termination, and optical specification.
        """
        return pulumi.get(self, "circuit_type")

    @property
    @pulumi.getter(name="crossConnectId")
    def cross_connect_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cross-connect.
        """
        return pulumi.get(self, "cross_connect_id")

    @property
    @pulumi.getter(name="facilityLocation")
    def facility_location(self) -> str:
        """
        The address of the FastConnect location.
        """
        return pulumi.get(self, "facility_location")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="portName")
    def port_name(self) -> str:
        """
        The meet-me room port for this cross-connect.
        """
        return pulumi.get(self, "port_name")

    @property
    @pulumi.getter(name="timeExpires")
    def time_expires(self) -> str:
        """
        The date and time when the Letter of Authority expires, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_expires")

    @property
    @pulumi.getter(name="timeIssued")
    def time_issued(self) -> str:
        """
        The date and time the Letter of Authority was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_issued")


class AwaitableGetLetterOfAuthorityResult(GetLetterOfAuthorityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLetterOfAuthorityResult(
            authorized_entity_name=self.authorized_entity_name,
            circuit_type=self.circuit_type,
            cross_connect_id=self.cross_connect_id,
            facility_location=self.facility_location,
            id=self.id,
            port_name=self.port_name,
            time_expires=self.time_expires,
            time_issued=self.time_issued)


def get_letter_of_authority(cross_connect_id: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLetterOfAuthorityResult:
    """
    This data source provides details about a specific Letter Of Authority resource in Oracle Cloud Infrastructure Core service.

    Gets the Letter of Authority for the specified cross-connect.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_letter_of_authority = oci.Core.get_letter_of_authority(cross_connect_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str cross_connect_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cross-connect.
    """
    __args__ = dict()
    __args__['crossConnectId'] = cross_connect_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getLetterOfAuthority:getLetterOfAuthority', __args__, opts=opts, typ=GetLetterOfAuthorityResult).value

    return AwaitableGetLetterOfAuthorityResult(
        authorized_entity_name=__ret__.authorized_entity_name,
        circuit_type=__ret__.circuit_type,
        cross_connect_id=__ret__.cross_connect_id,
        facility_location=__ret__.facility_location,
        id=__ret__.id,
        port_name=__ret__.port_name,
        time_expires=__ret__.time_expires,
        time_issued=__ret__.time_issued)


@_utilities.lift_output_func(get_letter_of_authority)
def get_letter_of_authority_output(cross_connect_id: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLetterOfAuthorityResult]:
    """
    This data source provides details about a specific Letter Of Authority resource in Oracle Cloud Infrastructure Core service.

    Gets the Letter of Authority for the specified cross-connect.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_letter_of_authority = oci.Core.get_letter_of_authority(cross_connect_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str cross_connect_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cross-connect.
    """
    ...
